@@ -16,7 +16,7 @@ BEGIN {
   *_HAVE_PERLSTRING = defined &B::perlstring ? sub(){1} : sub(){0};
 }
 
-our $VERSION = '2.006_000';
+our $VERSION = '2.006_001';
 $VERSION = eval $VERSION;
 
 our @EXPORT = qw(quote_sub unquote_sub quoted_from_sub qsub);
@@ -33,7 +33,11 @@ sub quotify {
     && length( (my $dummy = '') & $value )
     && 0 + $value eq $value
   ) ? (
-    $value != $value ? 'CORE::sin(9**9**9)' # nan
+    $value != $value ? (
+      $value eq -CORE::sin(9**9**9)
+        ? '(-CORE::sin(9**9**9))' # -nan
+        : 'CORE::sin(9**9**9)'    # nan
+    )
     : $value == 9**9**9 ? '(9**9**9)'      # inf
     : $value == -9**9**9 ? '(-9**9**9)'    # -inf
     : int($value) == $value ? $value       # integer
